# gecko
Async object mapping for Redis and Python.

## Development Status

Gecko-om is still in active development and is not yet ready for use. To contribute, see the section below.

## Contributing

For guidance on setting up a development environment and how to make a
contribution to gecko-om, see
[Contributing to Gecko-om](CONTRIBUTING.md).


## Reporting a Security Vulnerability

Please send a private mail to `lordunyime@gmail.com` if you discover any security vulnerability. I'll be happy to work with you on a fix.